# Generated by Django 5.2.9 on 2025-12-16 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('currency', '0001_initial'),
        ('io', '0008_importsource_resource_kwargs'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='currencyfxrates',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='currencyfxrates',
            constraint=models.UniqueConstraint(fields=('date', 'currency'), name='unique_currency'),
        ),
    ]
