# Generated by Django 5.2.9 on 2025-12-16 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('io', '0008_importsource_resource_kwargs'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='importedobjectproviderrelationship',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='parserhandler',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='importedobjectproviderrelationship',
            constraint=models.UniqueConstraint(fields=('content_type', 'object_id', 'provider'), name='unique_contentobjectprovideridentifierrelationship'),
        ),
        migrations.AddConstraint(
            model_name='importedobjectproviderrelationship',
            constraint=models.UniqueConstraint(fields=('content_type', 'provider_identifier', 'provider'), name='unique_contentobjectprovideridentifier'),
        ),
        migrations.AddConstraint(
            model_name='parserhandler',
            constraint=models.UniqueConstraint(fields=('parser', 'handler'), name='unique_parserhandler'),
        ),
    ]
