# Generated by Django 5.2.9 on 2025-12-09 08:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('directory', '0013_alter_clientmanagerrelationship_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='entry',
            name='relationship_managers',
            field=models.ManyToManyField(blank=True, help_text='People in charge of this entry', related_name='clients', through='directory.ClientManagerRelationship', through_fields=('client', 'relationship_manager'), to='directory.person', verbose_name='Relationship Managers'),
        ),
        migrations.AlterField(
            model_name='entry',
            name='relationships',
            field=models.ManyToManyField(blank=True, through='directory.Relationship', through_fields=('from_entry', 'to_entry'), to='directory.entry', verbose_name="The Entry's Relationships"),
        ),
        migrations.AlterField(
            model_name='person',
            name='employers',
            field=models.ManyToManyField(blank=True, help_text="The person's employers", related_name='employees', through='directory.EmployerEmployeeRelationship', through_fields=('employee', 'employer'), to='directory.company', verbose_name='Employers'),
        ),
    ]
