# Generated by Django 5.2.9 on 2025-12-16 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0006_auto_20231206_1422'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='token',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='token',
            constraint=models.UniqueConstraint(fields=('user', 'protected_view_name'), name='unique_token'),
        ),
    ]
