# Generated by Django 5.2.9 on 2025-12-09 08:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geography', '0001_initial'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='geography',
            index=models.Index(fields=['tree_id', 'lft'], name='geography_geography_tree_i739a'),
        ),
    ]
